EvalCtx

Struct EvalCtx 

pub struct EvalCtx<'r> {
    pub ctx: Context,
    pub registry: &'r Registry,
}
Bundles the variable context and function registry for use during evaluation. Passed to lazy functions so they can recursively evaluate sub-expressions.

Fields

ctx: Contextregistry: &'r Registry

Implementations

Source

impl<'r> EvalCtx<'r>

pub fn new(ctx: Context, registry: &'r Registry) -> Self