pub fn validate(formula: &str) -> Result<(), ParseError>Expand description
Validate that a formula string is syntactically correct without returning the AST.
pub fn validate(formula: &str) -> Result<(), ParseError>Validate that a formula string is syntactically correct without returning the AST.