pub struct Context {
pub vars: HashMap<String, Value>,
}Expand description
Holds the named variable bindings for a formula evaluation.
All keys are stored and looked up in uppercase, so variable names are
case-insensitive (A1, a1, and A1 all refer to the same binding).
Fields
vars: HashMap<String, Value>Implementations